@@ -1,8 +1,10 @@
 """Overly general Python library used when no other library is a good fit."""
 
-from .bugyi_lib import dummy
+import logging as _logging
 
 
 __author__ = "Bryan M Bugyi"
 __email__ = "bryanbugyi34@gmail.com"
-__version__ = "0.5.0"
+__version__ = "0.6.1"
+
+_logging.getLogger(__name__).addHandler(_logging.NullHandler())
